@@ -1,6 +1,11 @@
-from numpy import array
-import numpy as np
+# from numpy import array
+# import numpy as np
 from numpy import load
+from os import chdir
+from os.path import abspath,join
+
+
+
 names = {
     "data_path": "/work/papers/data",
     "paper_path": "/work/papers",
@@ -11,7 +16,14 @@ PAPER = "/work/papers"
 
 
 def get_vol6_64(nums: int):
-    data = load('./vol6_64.npy')
+    import sys
+    # dir_path = abspath('tool.py')
+    # print(sys.path[0])
+    # chdir(dir_path[0])
+    real_path = join(sys.path[0],'./vol6_64.npy')
+    # abs_path = abspath('tool.py')
+    # print(abs_path)
+    data = load(real_path)
     if nums > data.shape[0]:
         print('Warning: max size is ', data.shape[0])
     return data[0:nums]
@@ -22,4 +34,4 @@ def get_vol6_64(nums: int):
 # print(x.shape)
 # print(x[0:1010].shape)
 
-# get_vol6_64(10221)
\ No newline at end of file
+get_vol6_64(10221)
\ No newline at end of file
